gr_reply_input

Function gr_reply_input 

pub unsafe extern "C" fn gr_reply_input(
    offset: Offset,
    len: Length,
    value: *const Value,
    err_mid: *mut ErrorWithHash,
)
Fallible gr_reply_input send syscall.

Arguments type:

  • offset: u32 defining start index of the input buffer to use.
  • len: u32 defining slice length of the input buffer to use.
  • value: const ptr for u128 defining amount of value to apply. Ignored if equals u32::MAX (use this for zero value for optimization).
  • err_mid: mut ptr for concatenated error code and message id.