pub unsafe extern "C" fn gr_reply_input(
offset: Offset,
len: Length,
value: *const Value,
err_mid: *mut ErrorWithHash,
)Expand description
Fallible gr_reply_input send syscall.
Arguments type:
offset:u32defining start index of the input buffer to use.len:u32defining slice length of the input buffer to use.value:const ptrforu128defining amount of value to apply. Ignored if equals u32::MAX (use this for zero value for optimization).err_mid:mut ptrfor concatenated error code and message id.